==> igniteui-react-charts-16.4.1.tgz: package/ES2015/PriceChannelOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Type, Number_$type, typeCast, runOn, markType, Point_$type, fromEnum } from "igniteui-react-core/ES2015/type";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { MathUtil } from "igniteui-react-core/ES2015/MathUtil";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core/ES2015/Polyline";
import { Polygon } from "igniteui-react-core/ES2015/Polygon";
import { RangeValueList } from "./RangeValueList";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { Flattener } from "igniteui-react-core/ES2015/Flattener";
export class PriceChannelOverlay extends FinancialOverlay {
    constructor() {
        super();
        this.pg = new List$1(Number_$type, 0);
        this.pf = new List$1(Number_$type, 0);
        this.ab = PriceChannelOverlay.$;
        this.l2 = new CategoryFrame(3);
        this.l4 = new CategoryFrame(3);
        this.l1 = new CategoryFrame(3);
    }
    ir(a, b, c, d) {
        switch (b) {
            case "HighColumn":
            case "LowColumn":
                this.o9 = false;
                break;
        }
        super.ir(a, b, c, d);
        switch (b) {
            case PriceChannelOverlay.$$p[0]:
                this.o9 = false;
                this.i4(false);
                break;
        }
    }
    du(a, b, c) {
        let d = super.du(a, b, c);
        if (this.mp == null || this.mr == null) {
            d = false;
        }
        return d;
    }
    pa() {
        this.pg.clear();
        this.pf.clear();
        let a = truncate(MathUtil.b(this.ph, 0, this.bz.count));
        let b = Math.min(this.mp.count, this.mr.count);
        let c = this.nj(this.mp);
        let d = this.nj(this.mr);
        for (let e = 0; e < b; e++) {
            let f = Math.min(a, e);
            let g = -1.7976931348623157E+308;
            let h = 1.7976931348623157E+308;
            for (let i = 0; i < f; i++) {
                if (!isNaN_(c.item(e - i))) {
                    g = Math.max(g, c.item(e - i));
                }
                if (!isNaN_(d.item(e - i))) {
                    h = Math.min(h, d.item(e - i));
                }
            }
            if (e == 0) {
                h = d.item(0);
                g = c.item(0);
            }
            this.pg.add(g);
            this.pf.add(h);
        }
        return true;
    }
    oq(a, b) {
        super.oq(a, b);
        let c = b.bq;
        let d = b.bp;
        let e = this.getEffectiveViewport1(b);
        let f = new ScalerParams(0, c, d, this.lz.b8, e);
        let g = new ScalerParams(0, c, d, this.mk.b8, e);
        g.b = this.ed();
        let h = this.lz;
        let i = this.mk;
        a.f.clear();
        a.m.clear();
        a.p.clear();
        let j = 0;
        let k = typeCast(ISortingAxis_$type, this.lz);
        if (k != null && k.i$b.count != this.bz.count) {
            return;
        }
        j = this.nq(c, d, e);
        if (!this.o9) {
            this.o9 = this.pa();
        }
        g.b = this.ed();
        let l = this.lz.dw(2, f) - this.lz.dw(1, f);
        for (let m = b.bs.c; m <= b.bs.d; ++m) {
            let n;
            if (k == null) {
                n = b.bs.getBucket(m);
            }
            else {
                let o = k.i$b._inner[m];
                let p = k.i$d(o);
                let q = this.pg._inner[m];
                let r = this.pf._inner[m];
                let s = q;
                let t = r;
                let u = p;
                while (m < b.bs.d) {
                    o = k.i$b._inner[m + 1];
                    u = k.i$d(o);
                    if (u - p > l) {
                        break;
                    }
                    m++;
                    s = Math.max(q, this.pg._inner[m]);
                    t = Math.min(r, this.pf._inner[m]);
                }
                if (!isInfinity(t) && !isInfinity(s)) {
                    let v = NaN;
                    if (!isNaN_(p)) {
                        v = this.lz.dt(p, f);
                    }
                    n = [v, t, s];
                }
                else {
                    n = [NaN, NaN, NaN];
                }
            }
            let w = Math.max(1, l);
            if (!isNaN_(n[0]) && m * w >= this.pb) {
                if (this.lz != null && typeCast(ISortingAxis_$type, this.lz) !== null) {
                    n[0] = n[0] + j;
                }
                else {
                    n[0] = h.dt(n[0], f) + j;
                }
                n[1] = i.dt(n[1], g);
                n[2] = i.dt(n[2], g);
                a.f.add(n);
            }
        }
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (c != null) {
            c.bz();
        }
    }
    os(a, b) {
        super.os(a, b);
        let c = typeCast(PriceChannelOverlayView.$, b);
        if (c == null) {
            return;
        }
        let d = this.getEffectiveViewport1(b);
        if (b.bv(a)) {
            c.bz();
            let e = a.f.count;
            let f = (g) => a.f._inner[g][0];
            let g = (h) => a.f._inner[e - 1 - h][0];
            let h = (i) => a.f._inner[i][1];
            let i = (j) => a.f._inner[e - 1 - j][2];
            c.b0(e, f, g, h, i);
            b.bx(a);
        }
        this.l7.x(this, this.m7(), this.lz, runOn(this, this.lr), this.nw(b), this.ny(b));
        let j = false;
        let k = this.l7.c;
        let l = a.f;
        let m = this.bz.count;
        if (k != null) {
            j = true;
        }
        if (j) {
            let n = new ScalerParams(0, b.bq, b.bp, this.lz.b8, d);
            this.op(l, -1, m, this.lz, n, b.n);
        }
        let o = c.b6;
        let p = c.b7;
        let q = c.b2;
        this.l7.ae(o, true, false, true, true);
        this.l7.ae(p, true, false, true, true);
        this.l7.ae(q, false, true, false, false);
        q._opacity = this.l7.i * this.d2;
    }
    bf() {
        return new PriceChannelOverlayView(this);
    }
    il(a) {
        super.il(a);
        this.pe = typeCast(PriceChannelOverlayView.$, a);
    }
    ej(a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        let d = this.getEffectiveViewport1(this.bi);
        let e = new ScalerParams(0, this.bs.ml, this.bi.bp, this.lz.b8, d);
        let f = this.nq(this.bs.ml, this.bi.bp, d);
        return this.el(new RangeValueList(this.pg, this.pf), a, this.lz, e, f, runOn(this, this.np), b, c);
    }
    e8(a, b) {
        if (this.pg == null || this.pf == null) {
            return super.e8(a, b);
        }
        return this.e9(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    }
    fa(a, b) {
        if (this.pg == null || this.pf == null) {
            return super.fa(a, b);
        }
        return this.fb(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    }
    ed() {
        return Series.ee(this.pf, null);
    }
}
PriceChannelOverlay.$t = markType(PriceChannelOverlay, 'PriceChannelOverlay', FinancialOverlay.$);
Type.dep(DependencyProperty, PropertyMetadata, PriceChannelOverlay, 'raisePropertyChanged', ['Period:ph:pj', [1, 14]]);
export class PriceChannelBucketCalculator extends FinancialBucketCalculator {
    constructor(a) {
        super(a);
        this.f = null;
        this.f = a;
    }
    getBucket(a) {
        let b = a * this.b;
        let c = Math.min(b + this.b - 1, this.a.bu.bz.count - 1);
        if (b <= c) {
            let d = -1.7976931348623157E+308;
            let e = 1.7976931348623157E+308;
            let f = 0;
            for (let g = b; g <= c; ++g) {
                if (!isNaN_(this.f.by.pg._inner[g]) && !isNaN_(this.f.by.pf._inner[g])) {
                    d = Math.max(d, this.f.by.pg._inner[g]);
                    e = Math.min(e, this.f.by.pf._inner[g]);
                    ++f;
                }
            }
            if (f > 0 && e != 1.7976931348623157E+308 && d != -1.7976931348623157E+308) {
                return [0.5 * (b + c), e, d];
            }
        }
        return [NaN, NaN, NaN];
    }
}
PriceChannelBucketCalculator.$t = markType(PriceChannelBucketCalculator, 'PriceChannelBucketCalculator', FinancialBucketCalculator.$);
export class PriceChannelOverlayView extends FinancialSeriesView {
    constructor(a) {
        super(a);
        this.b3 = new Polygon();
        this.b8 = new Polyline();
        this.b9 = new Polyline();
        this.by = null;
        this.b1 = new Polygon();
        this.b4 = new Polyline();
        this.b5 = new Polyline();
        this.by = a;
    }
    get b2() {
        return this.b3;
    }
    get b6() {
        return this.b8;
    }
    get b7() {
        return this.b9;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    bt() {
        return new PriceChannelBucketCalculator(this);
    }
    bz() {
        this.b3.aj.clear();
        this.b8.aj.clear();
        this.b9.aj.clear();
        this.an();
    }
    b0(a, b, c, d, e) {
        for (let f of fromEnum(Flattener.d(a, b, d, this.e.eq))) {
            this.b3.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
            this.b8.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
        }
        for (let g of fromEnum(Flattener.d(a, c, e, this.e.eq))) {
            this.b3.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
            this.b9.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
        }
        this.an();
    }
    a9() {
        super.a9();
        this.b1.aj = this.b3.aj;
        this.b4.aj = this.b8.aj;
        this.b5.aj = this.b9.aj;
        let a = this.bk();
        this.b1._fill = a;
        this.b1._opacity = 1;
        this.b4._stroke = a;
        this.b4.ac = this.e.eu + 3;
        this.b5._stroke = a;
        this.b5.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.t(this.b1);
                a.u(this.b4);
                a.u(this.b5);
            }
            else {
                a.t(this.b3);
                a.u(this.b8);
                a.u(this.b9);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPolygonData(a, this.b3, "fill", ["Fill"]);
        this.e.a2.exportPolylineData(a, this.b8, "bottom", ["Lower", "Main"]);
        this.e.a2.exportPolylineData(a, this.b9, "top", ["Upper"]);
    }
}
PriceChannelOverlayView.$t = markType(PriceChannelOverlayView, 'PriceChannelOverlayView', FinancialSeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.PriceChannelOverlay" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.PriceChannelOverlay" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/PriceChannelOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Type, Number_$type, typeCast, runOn, markType, Point_$type, fromEnum } from "igniteui-react-core/ES2015/type";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { MathUtil } from "igniteui-react-core/ES2015/MathUtil";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core/ES2015/Polyline";
import { Polygon } from "igniteui-react-core/ES2015/Polygon";
import { RangeValueList } from "./RangeValueList";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { Flattener } from "igniteui-react-core/ES2015/Flattener";
export class PriceChannelOverlay extends FinancialOverlay {
    constructor() {
        super();
        this.pg = new List$1(Number_$type, 0);
        this.pf = new List$1(Number_$type, 0);
        this.ab = PriceChannelOverlay.$;
        this.l2 = new CategoryFrame(3);
        this.l4 = new CategoryFrame(3);
        this.l1 = new CategoryFrame(3);
    }
    ir(a, b, c, d) {
        switch (b) {
            case "HighColumn":
            case "LowColumn":
                this.o9 = false;
                break;
        }
        super.ir(a, b, c, d);
        switch (b) {
            case PriceChannelOverlay.$$p[0]:
                this.o9 = false;
                this.i4(false);
                break;
        }
    }
    du(a, b, c) {
        let d = super.du(a, b, c);
        if (this.mp == null || this.mr == null) {
            d = false;
        }
        return d;
    }
    pa() {
        this.pg.clear();
        this.pf.clear();
        let a = truncate(MathUtil.b(this.ph, 0, this.bz.count));
        let b = Math.min(this.mp.count, this.mr.count);
        let c = this.nj(this.mp);
        let d = this.nj(this.mr);
        for (let e = 0; e < b; e++) {
            let f = Math.min(a, e);
            let g = -1.7976931348623157E+308;
            let h = 1.7976931348623157E+308;
            for (let i = 0; i < f; i++) {
                if (!isNaN_(c.item(e - i))) {
                    g = Math.max(g, c.item(e - i));
                }
                if (!isNaN_(d.item(e - i))) {
                    h = Math.min(h, d.item(e - i));
                }
            }
            if (e == 0) {
                h = d.item(0);
                g = c.item(0);
            }
            this.pg.add(g);
            this.pf.add(h);
        }
        return true;
    }
    oq(a, b) {
        super.oq(a, b);
        let c = b.bs;
        let d = b.br;
        let e = this.getEffectiveViewport1(b);
        let f = new ScalerParams(0, c, d, this.lz.b8, e);
        let g = new ScalerParams(0, c, d, this.mk.b8, e);
        g.b = this.ed();
        let h = this.lz;
        let i = this.mk;
        a.f.clear();
        a.m.clear();
        a.p.clear();
        let j = 0;
        let k = typeCast(ISortingAxis_$type, this.lz);
        if (k != null && k.i$b.count != this.bz.count) {
            return;
        }
        j = this.nq(c, d, e);
        if (!this.o9) {
            this.o9 = this.pa();
        }
        g.b = this.ed();
        let l = this.lz.dw(2, f) - this.lz.dw(1, f);
        for (let m = b.bu.c; m <= b.bu.d; ++m) {
            let n;
            if (k == null) {
                n = b.bu.getBucket(m);
            }
            else {
                let o = k.i$b._inner[m];
                let p = k.i$d(o);
                let q = this.pg._inner[m];
                let r = this.pf._inner[m];
                let s = q;
                let t = r;
                let u = p;
                while (m < b.bu.d) {
                    o = k.i$b._inner[m + 1];
                    u = k.i$d(o);
                    if (u - p > l) {
                        break;
                    }
                    m++;
                    s = Math.max(q, this.pg._inner[m]);
                    t = Math.min(r, this.pf._inner[m]);
                }
                if (!isInfinity(t) && !isInfinity(s)) {
                    let v = NaN;
                    if (!isNaN_(p)) {
                        v = this.lz.dt(p, f);
                    }
                    n = [v, t, s];
                }
                else {
                    n = [NaN, NaN, NaN];
                }
            }
            let w = Math.max(1, l);
            if (!isNaN_(n[0]) && m * w >= this.pb) {
                if (this.lz != null && typeCast(ISortingAxis_$type, this.lz) !== null) {
                    n[0] = n[0] + j;
                }
                else {
                    n[0] = h.dt(n[0], f) + j;
                }
                n[1] = i.dt(n[1], g);
                n[2] = i.dt(n[2], g);
                a.f.add(n);
            }
        }
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (c != null) {
            c.b1();
        }
    }
    os(a, b) {
        super.os(a, b);
        let c = typeCast(PriceChannelOverlayView.$, b);
        if (c == null) {
            return;
        }
        let d = this.getEffectiveViewport1(b);
        if (b.bx(a)) {
            c.b1();
            let e = a.f.count;
            let f = (g) => a.f._inner[g][0];
            let g = (h) => a.f._inner[e - 1 - h][0];
            let h = (i) => a.f._inner[i][1];
            let i = (j) => a.f._inner[e - 1 - j][2];
            c.b2(e, f, g, h, i);
            b.bz(a);
        }
        this.l7.x(this, this.m7(), this.lz, runOn(this, this.lr), this.nw(b), this.ny(b));
        let j = false;
        let k = this.l7.c;
        let l = a.f;
        let m = this.bz.count;
        if (k != null) {
            j = true;
        }
        if (j) {
            let n = new ScalerParams(0, b.bs, b.br, this.lz.b8, d);
            this.op(l, -1, m, this.lz, n, b.n);
        }
        let o = c.b8;
        let p = c.b9;
        let q = c.b4;
        this.l7.ae(o, true, false, true, true);
        this.l7.ae(p, true, false, true, true);
        this.l7.ae(q, false, true, false, false);
        q._opacity = this.l7.i * this.d2;
    }
    bf() {
        return new PriceChannelOverlayView(this);
    }
    il(a) {
        super.il(a);
        this.pe = typeCast(PriceChannelOverlayView.$, a);
    }
    ej(a, b, c) {
        if (this.bs == null) {
            return NaN;
        }
        let d = this.getEffectiveViewport1(this.bi);
        let e = new ScalerParams(0, this.bs.mn, this.bi.br, this.lz.b8, d);
        let f = this.nq(this.bs.mn, this.bi.br, d);
        return this.el(new RangeValueList(this.pg, this.pf), a, this.lz, e, f, runOn(this, this.np), b, c);
    }
    e8(a, b) {
        if (this.pg == null || this.pf == null) {
            return super.e8(a, b);
        }
        return this.e9(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    }
    fa(a, b) {
        if (this.pg == null || this.pf == null) {
            return super.fa(a, b);
        }
        return this.fb(a, b, this.lz, runOn(this, this.np), new RangeValueList(this.pg, this.pf));
    }
    ed() {
        return Series.ee(this.pf, null);
    }
}
PriceChannelOverlay.$t = markType(PriceChannelOverlay, 'PriceChannelOverlay', FinancialOverlay.$);
Type.dep(DependencyProperty, PropertyMetadata, PriceChannelOverlay, 'raisePropertyChanged', ['Period:ph:pj', [1, 14]]);
export class PriceChannelBucketCalculator extends FinancialBucketCalculator {
    constructor(a) {
        super(a);
        this.f = null;
        this.f = a;
    }
    getBucket(a) {
        let b = a * this.b;
        let c = Math.min(b + this.b - 1, this.a.bw.bz.count - 1);
        if (b <= c) {
            let d = -1.7976931348623157E+308;
            let e = 1.7976931348623157E+308;
            let f = 0;
            for (let g = b; g <= c; ++g) {
                if (!isNaN_(this.f.b0.pg._inner[g]) && !isNaN_(this.f.b0.pf._inner[g])) {
                    d = Math.max(d, this.f.b0.pg._inner[g]);
                    e = Math.min(e, this.f.b0.pf._inner[g]);
                    ++f;
                }
            }
            if (f > 0 && e != 1.7976931348623157E+308 && d != -1.7976931348623157E+308) {
                return [0.5 * (b + c), e, d];
            }
        }
        return [NaN, NaN, NaN];
    }
}
PriceChannelBucketCalculator.$t = markType(PriceChannelBucketCalculator, 'PriceChannelBucketCalculator', FinancialBucketCalculator.$);
export class PriceChannelOverlayView extends FinancialSeriesView {
    constructor(a) {
        super(a);
        this.b5 = new Polygon();
        this.ca = new Polyline();
        this.cb = new Polyline();
        this.b0 = null;
        this.b3 = new Polygon();
        this.b6 = new Polyline();
        this.b7 = new Polyline();
        this.b0 = a;
    }
    get b4() {
        return this.b5;
    }
    get b8() {
        return this.ca;
    }
    get b9() {
        return this.cb;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    bv() {
        return new PriceChannelBucketCalculator(this);
    }
    b1() {
        this.b5.aj.clear();
        this.ca.aj.clear();
        this.cb.aj.clear();
        this.an();
    }
    b2(a, b, c, d, e) {
        for (let f of fromEnum(Flattener.d(a, b, d, this.e.eq))) {
            this.b5.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
            this.ca.aj.add({ $type: Point_$type, x: b(f), y: d(f) });
        }
        for (let g of fromEnum(Flattener.d(a, c, e, this.e.eq))) {
            this.b5.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
            this.cb.aj.add({ $type: Point_$type, x: c(g), y: e(g) });
        }
        this.an();
    }
    a9() {
        super.a9();
        this.b3.aj = this.b5.aj;
        this.b6.aj = this.ca.aj;
        this.b7.aj = this.cb.aj;
        let a = this.bl();
        this.b3._fill = a;
        this.b3._opacity = 1;
        this.b6._stroke = a;
        this.b6.ac = this.e.eu + 3;
        this.b7._stroke = a;
        this.b7.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.t(this.b3);
                a.u(this.b6);
                a.u(this.b7);
            }
            else {
                a.t(this.b5);
                a.u(this.ca);
                a.u(this.cb);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPolygonData(a, this.b5, "fill", ["Fill"]);
        this.e.a2.exportPolylineData(a, this.ca, "bottom", ["Lower", "Main"]);
        this.e.a2.exportPolylineData(a, this.cb, "top", ["Upper"]);
    }
}
PriceChannelOverlayView.$t = markType(PriceChannelOverlayView, 'PriceChannelOverlayView', FinancialSeriesView.$);
